@@ -3,7 +3,6 @@ package Catalyst::Engine::FCGI;
 use strict;
 use base 'Catalyst::Engine::CGI';
 use FCGI;
-use NEXT;
 
 =head1 NAME
 
@@ -31,14 +30,7 @@ sub run {
     my $class   = shift;
     my $request = FCGI::Request();
     while ( $request->Accept() >= 0 ) {
-        my $output;
-        {
-            local (*STDOUT);
-            open( STDOUT, '>', \$output );
-            $class->NEXT::run;
-        }
-        $output =~ s!^HTTP/\d+.\d+ \d\d\d.*?\n!!s;
-        print $output;
+        $class->handler;
     }
 }
 
